@@ -21,6 +21,10 @@ use Data::Dumper;
 use Data::Dump qw(dump);
 #use Sub::Signatures;
 use Sim::OPT;
+use Sim::OPT::Morph;
+use Sim::OPT::Retrieve;
+use Sim::OPT::Report;
+use Sim::OPT::Descend;
 use feature 'say';
 no strict; 
 no warnings;
@@ -31,7 +35,7 @@ no warnings;
 
 @EXPORT = qw( sim ); # our @EXPORT = qw( );
 
-$VERSION = '0.37'; # our $VERSION = '';
+$VERSION = '0.39.6_5'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -46,15 +50,9 @@ $VERSION = '0.37'; # our $VERSION = '';
 #____________________________________________________________________________
 # Activate or deactivate the following function calls depending from your needs
 
-sub getglobsals
-{
-	$configfile = shift;
-	
-}
-
 sub sim    # This function launch the simulations in ESP-r
 {
-	say "\nIn Sim::OPT::Sim.\n";
+	say "\nNow in Sim::OPT::Sim.\n";
 	my $swap = shift;
 	my %dat = %$swap;
 	my @instances = @{ $dat{instances} };
@@ -65,8 +63,6 @@ sub sim    # This function launch the simulations in ESP-r
 	my %globs = %{ $dat{globs} };
 	
 	$configfile = $dat{configfile}; #say "dump(\$configfile): " . dump($configfile);
-	
-	$filenew = "$file"."_";
 
 	my @simcases = @{ $dat{simcases} };
 	my @simstruct = @{ $dat{simstruct} };
@@ -123,16 +119,14 @@ sub sim    # This function launch the simulations in ESP-r
 	my @maketabledata = @main::maketabledata;
 	my @filter_columns = @main::filter_columns;
 	
-	my $filenew = "$file"."_";
-	
 	#my $getpars = shift;
 	#eval( $getpars );
 	
-	my $toshellsim = "$toshell" . "-2sim.txt";
-	my $outfilesim = "$outfile" . "-2sim.txt";
+	#my $toshellsim = "$toshell" . "-2sim.txt";
+	#my $outfilesim = "$outfile" . "-2sim.txt";
 		
-	open ( TOSHELLSIM, ">>$toshellsim" );
-	open ( OUTFILESIM, ">>$outfilesim" );
+	#open ( TOSHELL, ">>$toshellsim" );
+	#open ( OUTFILE, ">>$outfilesim" );
 	
 	open ( SIMLIST, ">$simlist") or ( say "\$simlist: $simlist" and die );
 	
@@ -161,9 +155,13 @@ sub sim    # This function launch the simulations in ESP-r
 			open ( SIMBLOCK, ">>$simblock"); # or die;
 		}
 	}
+	
+	open ( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
+	open ( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
 
 	foreach my $instance (@instances)
 	{
+		say "\nNow in Sim::OPT::Sim.\n";
 		my %dat = %{$instance};
 		my @rootnames = @{ $dat{rootnames} }; #say \"dump(\@rootnames): " . dump(@rootnames);
 		my $countcase = $dat{countcase}; #say "dump(\$countcase): " . dump($countcase);
@@ -261,7 +259,10 @@ XXX
 							{
 								print `$printthis`;
 							}
-							print TOSHELLSIM $printthis;
+							print TOSHELL "  
+#Simulating zones for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance.
+$printthis
+";
 						}
 					
 						if ( $simnetwork eq "y" )
@@ -294,8 +295,11 @@ XXX
 							{
 								print `$printthis`;
 							}
-							print TOSHELLSIM $printthis;
-							print OUTFILESIM "TWO, $resfile\n";
+							print TOSHELL " 
+#Simulating zones for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance.\
+$printthis
+\n";
+							print OUTFILE "TWO, $resfile\n";
 						}						
 					}
 				}		
@@ -307,8 +311,8 @@ XXX
 
 	close SIMLIST;
 	close SIMBLOCK;
-	close TOSHELLSIM;
-	close OUTFILESIM;
+	#close TOSHELL;
+	#close OUTFILE;
 }    # END SUB sim;			
 
 # END OF THE CONTENT OF Sim::OPT::Sim
